pub fn parse_inline_str(s: &str) -> Vec<Node>Expand description
Lex s and run the inline parser on it. Returns the inline Node
list (Text, InlineCode, Bold, Italic, Strikethrough, Link, …).
Used by table cells, which receive raw cell strings rather than
pre-tokenised inline content.